Crate c6000_disassembler

Crate c6000_disassembler 

Modules

instruction

Constants

COMPACT_INSTRUCTION_SIZE
Size of a compact instruction in bytes
INSTRUCTION_SIZE
Size of a regular instruction in bytes
PACKET_SIZE
Size of an FP (Fetch Packet) in bytes

Functions

read_compact_instruction
Reads a compact 16-bit instruction and returns a result containing a struct with the C6000Instruction trait.
read_instruction
Reads a 32-bit instruction and returns a result containing a struct with the C6000Instruction trait.
read_packet