pub fn read_compact_instruction(
input: InstructionInput,
) -> Result<Box<dyn C6000Instruction>>Expand description
Reads a compact 16-bit instruction and returns a result containing a struct with the C6000Instruction trait.
pub fn read_compact_instruction(
input: InstructionInput,
) -> Result<Box<dyn C6000Instruction>>Reads a compact 16-bit instruction and returns a result containing a struct with the C6000Instruction trait.