pub fn read_instruction(
input: InstructionInput,
) -> Result<Box<dyn C6000Instruction>>Expand description
Reads a 32-bit instruction and returns a result containing a struct with the C6000Instruction trait.
pub fn read_instruction(
input: InstructionInput,
) -> Result<Box<dyn C6000Instruction>>Reads a 32-bit instruction and returns a result containing a struct with the C6000Instruction trait.