CompactInstructionHeader

Struct CompactInstructionHeader 

pub struct CompactInstructionHeader {
    pub layout: [bool; 7],
    pub loads_protected: bool,
    pub register_set: bool,
    pub primary_data_size: DataSize,
    pub secondary_data_size: DataSize,
    pub decode_compact_branches: bool,
    pub saturate: bool,
    pub compact_p_bits: [bool; 14],
    /* private fields */
}

Fields

layout: [bool; 7]

Layout field Determines if the i-th word holds two compact (16-bit) instructions (true) or a regular, 32-bit instruction (false).

loads_protected: bool

PROT field. Determines if 4 NOP cycles are added after every LD instruction.

register_set: bool

RS field. Determines if instructions use high register set for data source and destination (true) or low register set (false).

primary_data_size: DataSizesecondary_data_size: DataSizedecode_compact_branches: bool

BR field. Determines if compact instructions in the S unit are decoded as branches.

saturate: bool

SAT field. Determines if instructions are saturated.

As a result, ADD, SUB, SHL, MPY, MPYH, MPYLH and MPYHL instructions are decoded as SADD, SUBS, SSHL, SMPY, SMPYH, SMPYLH and SMPYHL respectively.

compact_p_bits: [bool; 14]