Modules
Constants
- COMPACT_
INSTRUCTION_ SIZE - Size of a compact instruction in bytes
- INSTRUCTION_
SIZE - Size of a regular instruction in bytes
- PACKET_
SIZE - Size of an FP (Fetch Packet) in bytes
Functions
- read_
compact_ instruction - Reads a compact 16-bit instruction and returns a result containing a struct with the C6000Instruction trait.
- read_
instruction - Reads a 32-bit instruction and returns a result containing a struct with the C6000Instruction trait.
- read_
packet